{% load static %}
<script defer type="application/javascript" src="{% static 'django_glue/js/vendor/alpine_focus.min.js' %}?v={{ DJANGO_GLUE_VERSION }}"></script>
<script defer type="application/javascript" src="{% static 'django_glue/js/vendor/alpine.min.js' %}?v={{ DJANGO_GLUE_VERSION }}"></script>
