{% load static %}
<link rel="stylesheet" href="{% static 'django_glue/css/vendor/bootstrap.min.css' %}?v={{ DJANGO_GLUE_VERSION }}">
<link rel="stylesheet" href="{% static 'django_glue/css/glue.css' %}?v={{ DJANGO_GLUE_VERSION }}">
