{% extends 'django_glue/form/glue_field/item/select_choice_item.html' %}

{% block choice_checkmark %}
    {% include 'django_glue/form/glue_field/element/select_checkmark_element.html' %}
{% endblock %}