# Generated by Django 4.2.7 on 2024-06-15 04:31

from django.db import migrations, models
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ('tests', '0005_testmodel_bed_time'),
    ]

    operations = [
        migrations.CreateModel(
            name='UuidTestModel',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('title', models.CharField(max_length=32)),
            ],
        ),
        migrations.AlterField(
            model_name='testmodel',
            name='bed_time',
            field=models.TimeField(default='20:00'),
        ),
    ]
